Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(982)

Unified Diff: media/base/sample_format.h

Issue 2503233003: Add enumerations for compressed (E)AC3 sample format (Closed)
Patch Set: Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: media/base/sample_format.h
diff --git a/media/base/sample_format.h b/media/base/sample_format.h
index 24bbe4f59ed7cc41643021e6e7547ef0fd6cf9f2..2e55ad0df6227d4ab5c630661fd7cafc3d5df6f4 100644
--- a/media/base/sample_format.h
+++ b/media/base/sample_format.h
@@ -15,17 +15,19 @@ enum SampleFormat {
// adding a sample format, do so at the bottom before kSampleFormatMax, and
// update the value of kSampleFormatMax.
kUnknownSampleFormat = 0,
- kSampleFormatU8, // Unsigned 8-bit w/ bias of 128.
- kSampleFormatS16, // Signed 16-bit.
- kSampleFormatS32, // Signed 32-bit.
- kSampleFormatF32, // Float 32-bit.
- kSampleFormatPlanarS16, // Signed 16-bit planar.
- kSampleFormatPlanarF32, // Float 32-bit planar.
- kSampleFormatPlanarS32, // Signed 32-bit planar.
- kSampleFormatS24, // Signed 24-bit.
+ kSampleFormatU8, // Unsigned 8-bit w/ bias of 128.
+ kSampleFormatS16, // Signed 16-bit.
+ kSampleFormatS32, // Signed 32-bit.
+ kSampleFormatF32, // Float 32-bit.
+ kSampleFormatPlanarS16, // Signed 16-bit planar.
+ kSampleFormatPlanarF32, // Float 32-bit planar.
+ kSampleFormatPlanarS32, // Signed 32-bit planar.
+ kSampleFormatS24, // Signed 24-bit.
+ kSampleFormatBitstreamAc3, // Compressed AC3 bitstream.
DaleCurtis 2016/11/17 00:02:15 Just kSampleFormatAC3, ditto for EAC3?
AndyWu 2016/11/17 18:56:55 Done.
+ kSampleFormatBitstreamEac3, // Compressed E-AC3 bitstream.
// Must always be equal to largest value ever logged.
- kSampleFormatMax = kSampleFormatS24,
+ kSampleFormatMax = kSampleFormatBitstreamEac3,
};
// Returns the number of bytes used per channel for the specified
@@ -41,6 +43,9 @@ MEDIA_EXPORT bool IsPlanar(SampleFormat sample_format);
// Returns true if |sample_format| is interleaved, false otherwise.
MEDIA_EXPORT bool IsInterleaved(SampleFormat sample_format);
+// Returns true if |sample_format| is compressed bitstream, false otherwise.
+MEDIA_EXPORT bool IsCompressed(SampleFormat sample_format);
+
} // namespace media
#endif // MEDIA_BASE_SAMPLE_FORMAT_H_

Powered by Google App Engine
This is Rietveld 408576698